@@ -1,4 +1,4 @@
-
+#!/usr/bin/python
 ###The MIT License
 
 #Copyright (c) 2010  andrea cadeddu, mrernia@gmail.com
@@ -33,23 +33,60 @@ class MyWidget(HildonHomePluginItem):
         #body = gtk.Label("This is the body\nline2\nline3")
         #self.add(body)
         self.show_all()
+	self.loadpic()
+	
+
+    def loadpic(self):
+	import os
         today=time.strftime("%Y%m%d",time.gmtime())+".png"
-        fname='/home/user/.todoy/'+today
-        pb = gtk.gdk.pixbuf_new_from_file(fname) #was pixbug
-	i = gtk.Image()
+        self.fname='/home/user/.todoy/'+today
+	if not os.path.exists(self.fname):
+		self.fname='/opt/todoy/todoy_bkgrnd.png'
+        pb = gtk.gdk.pixbuf_new_from_file(self.fname) #was pixbug
+	
+	self.i = gtk.Image()
 	height=(800*2)/3
 	width=(350 *2)/3
 	scaled_buf = pb.scale_simple(height,width,gtk.gdk.INTERP_BILINEAR)
 	#pb.set_size_request(250,250)
         #s.set_size_request(200,200)
-        i.set_from_pixbuf(scaled_buf)
-        i.show_all()
-        self.add(i)
+        self.i.set_from_pixbuf(scaled_buf)
+        self.i.show_all()
+        self.add(self.i)
 #	self.button = gtk.Button("Hello World")
 #	self.button.connect_object("clicked", print("ay"), self.window)
 
-def myfun(num):
-	print num
+    def refresh(self):
+	self.i.hide()
+	#self.clear()
+	self.loadpic()
+
+    def launchtodoy(self):
+	import subprocess
+	subprocess.Popen("/usr/bin/todoy")
+	pass
+
+    def click_down(self, widget, event):
+	
+        self.active = True
+
+        widget.queue_draw()
+
+	self.refresh()
+	#event.type
+	#print event.time
+	if event.type==6: #tripledoubleclick
+		#print "ha!"
+		self.launchtodoy()
+		
+
+
+    def click_up(self, widget, event):
+        self.active = False
+        widget.queue_draw()
+
+
+
 
 
 hd_plugin_type = MyWidget
@@ -59,5 +96,4 @@ if __name__ == '__main__':
     gobject.type_register(hd_plugin_type)
     obj = gobject.new(hd_plugin_type, plugin_id="plugin_id")
     obj.show()
-    obj.connect_object("clicked", myfyun, 3)	
     gtk.main()
